<?php
namespace Webkul\SalesforceConnector\Controller\Adminhtml\Products;

use Webkul\SalesforceConnector\Helper\Product;

class ExportProducts extends \Magento\Backend\App\Action
{
    protected $_resultPageFactory;
    protected $_categoryCollection;
    protected $_filter;
    protected $_helper;
    protected $_json;

    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Ui\Component\MassAction\Filter $filter,
        \Magento\Framework\Json\Helper\Data $jsonHelper,
        Product $helper
    ) {
        parent::__construct($context);
        $this->_resultPageFactory = $resultPageFactory;
        $this->_json = $jsonHelper;
        $this->_helper = $helper;
        $this->_filter = $filter;
    }

    public function execute()
    {
        $result = ['skip' => 0 , 'err' => 0 ,'success' =>  0];
        if (\Webkul\SalesforceConnector\Helper\Connection::checkConnectionStatus()) {
            $params = $this->getRequest()->getParams();
            $total = $params['total'];
            $counter = $params['counter'];
            static $failure = 0;
            static $success = 0;
            $pdt_ids = $params['ids'];
            if (is_array($pdt_ids) && count($pdt_ids) > 0) {
                if (count($pdt_ids) >= 200) {
                    $this->messageManager->addError(__("Too Many selected. Use Export Instead"));
                } else {
                    list($comp, $error) = $this->_helper->exportProducts($pdt_ids);
                }
                    $success += $comp;
                    $failure += $error;
                    $result['success'] = $success;
                    $result['err'] = $failure;
            }
            if ($counter == $total) {
                
                if ($failure > 0) {
                    $this->messageManager
                    ->addError(__('Product(s) have not been Exported at Salesforce for more details check logs.', $failure));
                }
                if ($success > 0) {
                    $this->messageManager
                    ->addSuccess(__("Total %1 Product(s) has been successfully Exported at Salesforce.", $success));
                }
            }
        } else {
            $this->messageManager
                ->addError(__("Check Connection"));
        }
       
        $this->getResponse()->setHeader('Content-type', 'application/json');
        $this->getResponse()->setBody($this->_json->jsonEncode($result));
    }
}
